Decodable

Trait Decodable 

pub trait Decodable: Sized {
    type Error;

    // Required method
    fn decode(buf: &[u8]) -> Result<Self, Self::Error>;
}
A decodable type can be created from a byte buffer. The type returned is separate (copied) from the buffer once decoded.

Required Associated Types

Required Methods

fn decode(buf: &[u8]) -> Result<Self, Self::Error>

Decodes into a new object, or returns an error.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors